@@ -27,12 +27,20 @@ def user_is_login(account, html) -> bool:
     result = re.search(re_str, html)
     if result:
         return True
+
+    re_str = f'id="tips"'
+    result = re.search(re_str, html)
+    if not result:
+        return True
+
     doc = pq(html)
     err_msg = doc('#tips').text()
+
     if err_msg == "":
         return False
     # 错误流程
     if '验证码' in err_msg:
         return False
+    return False
     raise LoginException(400, err_msg)
 
